#
# spec file for package libyui-qt-pkg
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libyui-qt-pkg
Version:        2.45.12
Release:        2.1
Source:         %{name}-%{version}.tar.bz2

%define so_version 7
%define bin_name %{name}%{so_version}

BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  libyui-devel >= 3.0.4
BuildRequires:  pkg-config

%define libyui_qt_devel_version libyui-qt-devel >= 2.43.3
BuildRequires:  %{libyui_qt_devel_version}
%define libzypp_devel_version           libzypp-devel >= 15.14.0
BuildRequires:  %{libzypp_devel_version}

Url:            http://github.com/libyui/
Summary:        Libyui - Qt Package Selector
License:        LGPL-2.1 or LGPL-3.0
Group:          System/Libraries

%description
This package contains the Qt package selector
component for libYUI.


%package -n %{bin_name}

Requires:       libyui%{so_version}
Provides:       %{name} = %{version}

Provides:       yast2-qt-pkg = 2.42.0
Obsoletes:      yast2-qt-pkg < 2.42.0

Provides:       libyui_pkg
Supplements:    packageand(libyui-qt:yast2-packager)
# control center gnome requires graphical pkg and gtk is dropped (bnc#999031)
Supplements:    packageand(yast2-control-center-gnome:yast2-packager)

# new packager is in qt5 and crashes if qt3 diagsolver is used (bnc#870683)
Obsoletes:      libqdialogsolver1 < 1.4.0
Conflicts:      libqdialogsolver1 < 1.4.0

Url:            http://github.com/libyui/
Summary:        Libyui - Qt Package Selector
Group:          System/Libraries

%description -n %{bin_name}
This package contains the Qt package selector
component for libYUI.



%package devel

Requires:       %{bin_name} = %{version}
Requires:       %{libyui_qt_devel_version}
Requires:       %{libzypp_devel_version}

Url:            http://github.com/libyui/
Summary:        Libyui-qt-pkg header files
Group:          Development/Languages/C and C++

%description devel
This package contains the Qt package selector
component for libYUI.


This can be used independently of YaST for generic (C++) applications.
This package has very few dependencies.


%prep
%setup -q -n %{name}-%{version}

%build

export CFLAGS="$RPM_OPT_FLAGS -DNDEBUG"
export CXXFLAGS="$RPM_OPT_FLAGS -DNDEBUG"

./bootstrap.sh %{_prefix}

mkdir build
cd build

%if %{?_with_debug:1}%{!?_with_debug:0}
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELWITHDEBINFO
%else
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELEASE
%endif

make %{?jobs:-j%jobs}

%install
cd build
make install DESTDIR="$RPM_BUILD_ROOT"
install -m0755 -d $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/
install -m0755 -d $RPM_BUILD_ROOT/%{_libdir}/yui
install -m0644 ../COPYING* $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/

%clean
rm -rf "$RPM_BUILD_ROOT"

%post -n %{bin_name} -p /sbin/ldconfig

%postun -n %{bin_name} -p /sbin/ldconfig

%files -n %{bin_name}
%defattr(-,root,root)
%dir %{_libdir}/yui
%{_libdir}/yui/lib*.so.*
%doc %dir %{_docdir}/%{bin_name}
%doc %{_docdir}/%{bin_name}/COPYING*
%dir %{_prefix}/share/YaST2
%{_prefix}/share/YaST2/images

%files devel
%defattr(-,root,root)
%dir %{_docdir}/%{bin_name}
%{_libdir}/yui/lib*.so
%{_prefix}/include/yui
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}

%changelog
* Tue Nov 29 2016 shundhammer@suse.de
- Sort pkg list case-insensitively (bsc#1012294)
- 2.45.12
* Tue Nov  1 2016 jreidinger@suse.com
- avoid duplicate entries in package groups view (bnc#852073)
- 2.45.11
* Mon Oct 24 2016 jreidinger@suse.com
- install qt-pkg if graphical control center and yast2-packager is
  used to prevent crash (bsc#999031)
- 2.45.10
* Thu Oct 13 2016 igonzalezsosa@suse.com
- Adapt to the latest API change regarding QY2Styler,
  renaming usingHighContrastStyleSheet to usingAlternateStyleSheet
  (related to bsc#780621)
- 2.45.9
* Tue Oct 11 2016 igonzalezsosa@suse.com
- Use the new QY2Styler usingHighContrastStyleSheet instead of
  the old usingVisionImpairedPalette (related to bsc#780621)
- 2.45.8
* Mon Oct 10 2016 jreidinger@suse.com
- Improve message shown when user want to quit without saving
  changes (bsc#849084)
- 2.45.7
* Wed Nov 25 2015 gs@suse.de
- Respect /etc/zypp/zypp.conf settings for options "Allow vendor
  change" and "Cleanup when deleting packages" (bsc#954117)
- 2.45.6
* Tue Sep 22 2015 ancor@suse.com
- Better handling of secondary repository filters when there is
  no enough screen space (bnc#876540)
- 2.45.5
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Tue Sep  8 2015 shundhammer@suse.de
- Allow to delete single versions of multiversion packages
  (bsc#943870)
- 2.45.3
* Wed Aug 26 2015 shundhammer@suse.de
- Fixed crash in conflict resolver dialog:
  No longer call libzypp function that always returns null pointer
  (bsc#941398)
- 2.45.2
* Wed Aug 12 2015 shundhammer@suse.de
- Handle mixed multiversion packages (fate#318778)
- Fixed libzypp deprecated warning
- 2.45.1
* Mon Jun 22 2015 mvidner@suse.com
- Unified option handling with NCurses (FATE#318099)
  - "System verification mode" and "Dependencies/Autocheck"
    moved to /etc/sysconfig/yast2 (PKGMGR_VERIFY_SYSTEM,
    PKGMGR_AUTO_CHECK).
  - made "Cleanup when deleting packages" and "Allow vendor
    change" not persistent.
- Added option Dependencies/Install Recommended Packages,
  (PKGMGR_RECOMMENDED) (boo#900853).
- Changed "Options/Ignore Recommended Packages for Already
  Installed Packages" from an option to a command
  "Extras/Install All Matching Recommended Packages" (boo#902394).
- 2.45.0
* Tue Jan 20 2015 mvidner@suse.com
- Fix cmake also in the spec file, duh.
* Thu Jan 15 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (-fPIC, PREFIX, boo#911875).
- 2.44.8
* Tue Aug 26 2014 mvidner@suse.com
- Really added the libqdiagsolver conflict (bnc#870683, bnc#866622).
- 2.44.7
* Mon Jul 28 2014 mvidner@suse.com
- Recommend this package when yast2-packager and libyui-qt are
  installed (bnc#888300)
- 2.44.6
* Fri Jul  4 2014 jreidinger@suse.com
- Do not allow to run it together with libqdiagsolver in qt3
  version (bnc#870683, bnc#866622)
- 2.44.5
* Tue May 20 2014 mvidner@suse.com
- Fix showing package changelog, version, filelist (bnc#868101).
- 2.44.4
* Wed Mar 12 2014 mvidner@suse.com
- Fixed hard-coded colors and improved code to accept stylesheets.
- Fixed empty icons in the help dialog.
- Removed the tab close button near the upper-right corner:
  confusing.
- (all by tgoettlicher)
- 2.44.3
* Tue Mar  4 2014 mvidner@suse.com
- fix actions in the package context menu (bnc#866038)
- 2.44.2
* Tue Feb 25 2014 mvidner@suse.com
- Ported to Qt5
- 2.44.1
* Thu Feb 13 2014 mvidner@suse.com
- Removed hard-coded background color for pattern headline.
- 2.43.1
* Wed Jan  8 2014 mvidner@suse.com
- adjusted to libyui so version 6
- 2.43.0
* Fri Aug  2 2013 tgoettlicher@suse.de
- bnc#831758: fix symbol icons
- Version 2.42.13
* Tue Jul 30 2013 tgoettlicher@suse.de
- check pick list and installed obj for package classification
- Version 2.42.12
* Tue Jul 16 2013 tgoettlicher@suse.de
- use zypp setting as default value for "ignore recommended" menu
  entry (bnc#811237)
- Version 2.42.11
* Thu Jul 11 2013 tgoettlicher@suse.de
- fixed style issue in repository view (bnc#765790)
- Version 2.42.10
* Wed Jun 26 2013 tgoettlicher@suse.de
- removed webpin search (bnc#821866)
- Version 2.42.9
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- Version 2.42.8
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake
- Version 2.42.7
* Mon May  6 2013 tgoettlicher@suse.de
- Fixed so version
- Version 2.42.6
* Thu Jan 17 2013 tgoettlicher@suse.de
- Fixed endcoding of entries in package history (bnc #775608)
- Version 2.42.5
* Thu Jan 17 2013 tgoettlicher@suse.de
- Fixed encoding of tooltips (bnc# 764025)
- Version 2.42.4
* Wed Dec 12 2012 ma@suse.de
- Adapt to libzypps new history log parser API.
- Version 2.42.3
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Fri Apr 27 2012 tgoettlicher@suse.de
- Workaround for gcc 4.7 issues
- 2.21.24
* Thu Apr 26 2012 tgoettlicher@suse.de
- Added package group for unneeded packages
- 2.21.23
* Fri Mar 23 2012 tgoettlicher@suse.de
- Fixed bnc#704123: When updating packages, same version numbers in different repositories confuse YaST
- Version: 2.21.22
* Wed Mar 21 2012 tgoettlicher@suse.de
- Added shortcut to conflict dialog
- Version: 2.21.21
* Fri Mar 16 2012 tgoettlicher@suse.de
- Fixed bnc#722325: untranslated rpm groups
- Version: 2.21.20
* Tue Mar  6 2012 tgoettlicher@suse.de
- Fixed bnc#691572: Formatting Package Descriptions
- Version: 2.21.19
* Thu Jan 19 2012 tgoettlicher@suse.de
- Fixed bnc #734763: yast2 sw_single software management with QT ui
  resets columns in software view when horizontal scrollbar is removed
  (Patch from Frank Schäfer)
- Version: 2.21.18
* Thu Jan 19 2012 tgoettlicher@suse.de
- Fixed bnc#723151: Install all matching debuginfo packages" never
    finds anything-debuginfo-32bit
- Fixed bnc#730007: When updating packages, + keyshortcut doesn't
    always work
- Version: 2.21.17
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Nov 17 2011 tgoettlicher@suse.de
- Fixed bnc#722617: Yast2 package manager does not show icons of some packages
- Version: 2.21.16
* Tue Nov  8 2011 tgoettlicher@suse.de
- Fixed untranslated rpm package groups (bnc #722325)
- Version: 2.21.15
* Fri Nov  4 2011 tgoettlicher@suse.de
- Changed default for "Ignore recommended packages for already installed
  packages" (bnc #716017)
- Version: 2.21.14
* Mon Oct 24 2011 tgoettlicher@suse.de
- Fixed bnc#725953: Package manager settings are saved but not applied on start
- Version: 2.21.13
* Mon Oct 24 2011 tgoettlicher@suse.de
- Fixed bnc#721810: Disabled option "Ignore recommended packages for already installed
  packages" for update mode
- Version: 2.21.12
* Tue Oct 11 2011 tgoettlicher@suse.de
- Fixed bnc#718197: YaST2 Qt package manager opens RMB context
  menus at a wrong position, usability issue
- Version: 2.21.11
* Fri Oct  7 2011 tgoettlicher@suse.de
- Fixed bnc#718197: context menus at a wrong position
- 2.21.10
* Thu Oct  6 2011 tgoettlicher@suse.de
- Made settings persistant (fate #307220 )
- 2.21.9
* Wed Oct  5 2011 tgoettlicher@suse.de
- Applied Stano's patch to make installation history accessible
  from Yast GUI
- 2.21.8
* Tue Sep 20 2011 tgoettlicher@suse.de
- respect stylesheet in package selector
- 2.21.7
* Wed Aug 17 2011 tgoettlicher@suse.de
- fixed bnc#712191: Yast2 displays Cyrillic .desktop descriptions
- 2.21.6
* Thu Aug  4 2011 lslezak@suse.cz
- run the solver after changing "ignoreAlreadyRecommended" flag
  to reflect the change
* Tue Aug  2 2011 lslezak@suse.cz
- added new ignoreAlreadyRecommended solver option to the options
  submenu (bnc#668588)
- 2.21.5
* Thu Jun 30 2011 tgoettlicher@suse.de
- Fixed theme/color palette handling (bnc #637294)
- 2.21.4
* Fri May 27 2011 tgoettlicher@suse.de
- Fixed typo (bnc #696514)
- 2.21.3
* Wed Apr 27 2011 tgoettlicher@suse.de
- Added translation markers for RPM fields (bnc #686502)
- 2.21.2
* Wed Apr 27 2011 tgoettlicher@suse.de
- Enabled menu key to show context menu (bnc #681702)
- 2.21.1
* Thu Feb  3 2011 tgoettlicher@suse.de
- Fixed dependencies
- 2.20.3
* Thu Jan 13 2011 tgoettlicher@suse.de
- fixed preselected items in package list (bnc #661743)
- 2.20.2
* Tue Oct 12 2010 tgoettlicher@suse.de
- fixed bnc #422226: Switching patterns should scroll the
  package list back to the top
- 2.20.1
* Tue Jul 13 2010 dmacvicar@suse.de
- bnc#621649 patterns with no categories were supposed to be
  displayed at the top, not randomly
- 2.20.0
* Fri Apr 30 2010 tgoettlicher@suse.de
- Added solver options:
  * cleanup when deleting packages
  * allow vendor change
- 2.19.2
* Tue Apr 20 2010 tgoettlicher@suse.de
- Increased version number
- 2.19.1
* Thu Apr  1 2010 tgoettlicher@suse.de
- Fixed bnc #563923: Locked software package gets updated
- 2.18.22
* Thu Apr  1 2010 tgoettlicher@suse.de
- Fixed bnc #48761: yast doesn't respect locks
- 2.18.21
* Thu Mar 18 2010 tgoettlicher@suse.de
- Added libqt4 dependency (bnc #589104)
* Tue Feb  9 2010 tgoettlicher@suse.de
- added license headers
* Mon Jan 18 2010 tgoettlicher@suse.de
- fixed bnc #571200 - filter out 32 bit debuginfo packages
- V 2.18.20
* Mon Dec 21 2009 tgoettlicher@suse.de
- fixed bnc #564321: Alt-P shortcut overloaded in YaST2 Software Management
* Fri Dec  4 2009 tgoettlicher@suse.de
- Enabled multiple packages (fate# 305311)
- V 2.18.19
* Tue Dec  1 2009 tgoettlicher@suse.de
- fixed bnc #549868: Mnemonic clash in Software Management
- fixed bnc #554473: UTF-8 Problem
- fixed bnc #558881: Broken accented chars in YaST Qt packager versions tab
* Thu Nov 19 2009 tgoettlicher@suse.de
- fixed orphaned packages View (bnc #551771)
* Fri Oct 23 2009 dmacvicar@suse.de
- allow repository upgrades from the user interface
  (equivalent to zypper dup --from X ) (bnc#548551)
- V 2.18.18
* Thu Oct 22 2009 tgoettlicher@suse.de
- Fixed zypp dependency
- V 2.18.17
* Fri Oct 16 2009 tgoettlicher@suse.de
- Added group for orphaned packages
- V 2.18.16
* Thu Oct  8 2009 tgoettlicher@suse.de
- fixed bnc #539367: YaST Software Management, search function
  not registering secondary enter key.
* Thu Oct  1 2009 tgoettlicher@suse.de
- fixed bnc #543176: YaST2 cites 'supportability: unknown' for all packages
- V 2.18.15
* Mon Sep 28 2009 tgoettlicher@suse.de
- fixed bnc #532518: YaST in translation
- V 2.18.14
* Thu Sep 17 2009 tgoettlicher@suse.de
- Applied patch that fixes tabs by Fabien Crespel
- V 2.18.13
* Mon Sep 14 2009 tgoettlicher@suse.de
- Applied patch that fixes sorting by Fabien Crespel
- V 2.18.12
* Tue Sep  8 2009 tgoettlicher@suse.de
- Removed wrong package version from file list and change log view
  (#bnc 528750)
* Fri Aug 14 2009 tgoettlicher@suse.de
- Applied patch for optimal column width by Frank Schaefer
- V 2.18.11
* Tue Aug 11 2009 tgoettlicher@suse.de
- Fixed hard-coded font size in detail view (bnc #524225)
* Fri Jul 31 2009 tgoettlicher@suse.de
- Added repo priority and vendor to version view (bnc #503185)
* Thu Jul 30 2009 tgoettlicher@suse.de
- Fixed bnc #499699: position of search button in software management module
* Thu Jul 30 2009 tgoettlicher@suse.de
- Fixed buggy search in keywords (bnc #470069)
* Tue Jul 28 2009 tgoettlicher@suse.de
- Fixed closing tab mixes up view (bnc #513845)
* Mon Jul 27 2009 tgoettlicher@suse.de
- applied patch for autosize columns
- patch by Frank Schäfer
- tested by Dave Plater
- bnc #441828
- V 2.18.10
* Wed Jul 22 2009 kmachalkova@suse.cz
- Start webpin client from 'Configuration' menu (FaTE #306928)
* Thu May 28 2009 tgoettlicher@suse.de
- V 2.18.9
* Wed May 27 2009 ma@suse.de
- Remove use of deprecated Package::filenames.
* Fri Apr 24 2009 tgoettlicher@suse.de
- removed useless matchFiles()
- V 2.18.8
* Fri Apr  3 2009 tgoettlicher@suse.de
- Fixed confusion caused by patterns (bnc #476965)
- V 2.18.7
* Fri Apr  3 2009 tgoettlicher@suse.de
- Fixed view mode options (summaryMode, youMode) (bnc #490176)
* Thu Apr  2 2009 tgoettlicher@suse.de
- Fixed libzypp dependency
- V 2.18.6
* Tue Mar 17 2009 tgoettlicher@suse.de
- Fixed sort by version (bnc #467871)
* Fri Mar 13 2009 tgoettlicher@suse.de
- Added name of source package to technical detail view
* Thu Mar 12 2009 tgoettlicher@suse.de
- Fixed confusing system verification mode (bnc #285482)
- V 2.18.5
* Mon Mar  9 2009 tgoettlicher@suse.de
- Fixed "Unsupported Packages" confirmation when removing unsupported packages (bnc #475186)
* Thu Feb 26 2009 tgoettlicher@suse.de
- Fixed incorrect sort order in package list (bnc #469203)
* Tue Feb 24 2009 tgoettlicher@suse.de
- Fixed segfault when switching filters and version tab is shown
* Mon Feb  9 2009 tgoettlicher@suse.de
- Fixed support level wording in description view (bnc #470667)
* Wed Feb  4 2009 sh@suse.de
- Save and restore open tabs
- V 2.18.4
* Wed Feb  4 2009 tgoettlicher@suse.de
- Added application icons to description view
- Limited file list to 500 entries
- V 2.18.3
* Wed Feb  4 2009 sh@suse.de
- Added tab context menu (move left, move right, close)
* Thu Jan 29 2009 sh@suse.de
- Use tabs instead of combo box for switching filter views
  See also:
    http://preview.tinyurl.com/tabbed-pkg-browsing
    http://preview.tinyurl.com/tabbed-pkg-browsing-follow-up
- Moved PackageKit package groups filter view to separate class
- Restored RPM groups filter view
- V 2.18.2
* Mon Jan 12 2009 tgoettlicher@suse.de
- Fixed column widths in patch and language lists (bnc #461177)
* Fri Jan  9 2009 sh@suse.de
- Fixed accumulated margins in "Versions" view for installed
* Fri Jan  9 2009 sh@suse.de
- Fixed bnc #462778: Community repos show up as repo_1, repo_2, etc.
  in Versions view
* Fri Jan  2 2009 tgoettlicher@suse.de
- Fixed bnc #442161: don't sort package list after each status change
* Wed Dec 17 2008 sh@suse.de
- Applied kmachalkova's patch for bnc #399599: Search exact match
- V 2.18.1
* Mon Dec  8 2008 dmacvicar@suse.de
- package selector shows libzypp unsupported packages incorrectly
  (bnc #457214)
- V 2.17.25
* Mon Dec  8 2008 dmacvicar@suse.de
- Fix regression on package selector GUI speed.
  schedule layout of tree items for when the insertion of them
  is finished and we are back in the event loop.
  (bnc #457281)
- V 2.17.24
* Fri Dec  5 2008 dmacvicar@suse.de
- hide the solver information feature if the package is not
  present on the installation media (the popup has no sense there)
  (bnc #450065)
- V 2.17.23
* Tue Dec  2 2008 sh@suse.de
- Fixed bnc #450280: Text cut off in repository list
- V 2.17.22
* Fri Nov 28 2008 dmacvicar@suse.de
- fix displaying of automatic changes confirmations and
  unsupported packages confirmations.
- Needs fix in libzypp 5.24.2 so vendor unsupported packagages are
  marked correctly.
- V 2.17.21
* Tue Nov 25 2008 sh@suse.de
- Fixed fix for bnc #447273 (versions missing) that broke fix for
  bnc #441828 (column widths)
- V 2.17.20
* Mon Nov 24 2008 tgoettlicher@suse.de
- Fixed broken version column (bnc #447273)
- V 2.17.19
* Wed Nov 19 2008 sh@suse.de
- Fixed bnc #445415: No packages from patterns installed
- V 2.17.18
* Tue Nov 18 2008 sh@suse.de
- Fixed broken version numbers in change log
- V 2.17.17
* Thu Nov 13 2008 sh@suse.de
- Fixed over-wide buttons in dependency problem dialog
* Wed Nov 12 2008 sh@suse.de
- Improved table column widths (bnc #441828)
  still not perfect, but much better
* Wed Nov 12 2008 sh@suse.de
- Fixed over-wide [OK] button in package selector help
- V 2.17.16
* Wed Nov  5 2008 tgoettlicher@suse.de
- Fixed encoding in description view
* Mon Nov  3 2008 tgoettlicher@suse.de
- Fixed bnc #438680: software installation description not
  refreshed after search
* Fri Oct 31 2008 sh@suse.de
- Fixed bnc #381981: Bad initial size for secondary filters in
  "Repositories" filter view
- V 2.17.15
* Fri Oct 24 2008 sh@suse.de
- Fixed bnc #403367: Crash when searching for invalid regex
- V 2.17.14
* Tue Oct 21 2008 sh@suse.de
- Fixed bnc #436783: Map Amusements/Teaching/* to Education
- De-obfuscated RPM groups <--> PackageKit mapping
- V 2.17.13
* Wed Oct 15 2008 sh@suse.de
- Added `opt(`confirmUnsupported) for PackageSelector widget
  (bnc #435479)
- V 2.17.12
* Tue Oct 14 2008 sh@suse.de
- Fixed bnc #434042: "Install -devel packages" doesn't work
  with new library package naming scheme
* Mon Oct 13 2008 tgoettlicher@suse.de
- Fixed bnc #434259: Complete quotes for HTML attributes
* Thu Oct  9 2008 sh@suse.de
- Fixed bnc #433914: YQPkgDiskUsageWarningDialog too wide
- V 2.17.11
* Thu Oct  9 2008 sh@suse.de
- Fixed bnc #382202: WM_CLOSE closes window, but leaves y2base
  process running in undefined state
- V 2.17.10
* Tue Oct  7 2008 sh@suse.de
- Fixed bnc #429030: "Configuration" menu present in installation
- V 2.17.9
* Tue Oct  7 2008 sh@suse.de
- Fixed bnc #421267: Missing newline in exported conflicts list
* Thu Oct  2 2008 sh@suse.de
- Fixed bnc #430392: Typo in error message
* Wed Oct  1 2008 tgoettlicher@suse.de
- Fixed bnc #418279: export list to text file fails
* Fri Sep 26 2008 kmachalkova@suse.cz
- Fixed crash in Languages filter: redefined sort function for
  languages so that it does not refer to zypp::ResObjects
  (zypp::Locale isn't one anymore)(bnc#428355)
- V 2.17.8
* Thu Sep 11 2008 sh@suse.de
- Ask for package licenses, not patch licenses even in online
  update mode
- V 2.17.7
* Fri Sep  5 2008 sh@suse.de
- Fixed bnc #418676: Use title capitalization for groups
* Mon Aug 25 2008 tgoettlicher@suse.de
- fate #303458: Simplifiying Software Management
- V 2.17.6
* Thu Aug 21 2008 tgoettlicher@suse.de
- Fixed bnc #418606: widgets are not aligned
* Fri Aug 15 2008 dmacvicar@suse.de
- 2.17.5
- on SLE systems, warn before transaction if it includes
  unsupported software (fate#305057)
  can also be enabled by defining
  YPKG_QT_CONFIRM_UNSUPPORTED_PACKAGES at compile time.
- (fate#120366) search in file list option
* Thu Aug 14 2008 dmacvicar@suse.de
- 2.17.4
- make the versions view scrollable (bnc#409096)
* Tue Aug 12 2008 dmacvicar@suse.de
- package list should be sorted locale aware
  (bnc#355255)
* Mon Aug 11 2008 dmacvicar@suse.de
- Fixed bnc#394657 : package selector crashes when
  selecting languages with keyboard
* Tue Jul 29 2008 tgoettlicher@suse.de
- Fixed bnc #389174: changing packages with keyboard is broken
* Wed Jul 23 2008 ma@suse.de
- Remove references to obsolete freshens dependencies.
- V 2.17.3
* Thu Jul 17 2008 ma@suse.de
- Remove obsolete references to Script/Message/Atom
* Mon Jul 14 2008 dmacvicar@suse.de
- feature #302003, show transactions in a better way.
  basically we not only show automatic changes, but
  all changes or only user requested ones.
* Fri Jul 11 2008 sh@suse.de
- Fixed bnc #399674: Icons for Auto* actions missing in help
* Wed Jul  9 2008 sh@suse.de
- Fixed bnc #397082: No "[x] View -debugsource packages" menu entry:
  Now toggling -debuginfo and -debugsource simultaneously.
- Added "Install matching -debugsource packages" menu entry
- V 2.17.2
* Thu Jun 26 2008 schubi@suse.de
- Added plugin mechanism for displaying grafic solver results.
- V 2.17.1
* Wed Jun  4 2008 sh@suse.de
- Added translation marker for "File" menu (bnc #396419)
- V 2.16.48
* Thu May 29 2008 ma@suse.de
- Revert 'fix persistent locks saving (bnc#332853)' because the
  approach is wrong. Persistent locks are saved during commit.
  It's not the UI's task to do this.
- V 2.16.47
* Wed May 28 2008 sh@suse.de
- Applied Fabien Crespel's patch for repo sorting (bnc #394860)
- V 2.16.46
* Wed May 28 2008 locilka@suse.cz
- New version to follow standard way of submitting YaST packages
  (bnc #394977, bnc #394980, bnc #394504).
- 2.16.45
* Mon May 26 2008 coolo@suse.de
- fix encoding of pattern descriptions
* Mon May 26 2008 dmacvicar@suse.de
- bnc#394504 search kill YaST
* Fri May 23 2008 dmacvicar@suse.de
- if a patch is preselected it will go satisfied
  therefore it will not be shown in the "needed" list.
  Test for patches marked to be installed too.
* Wed May 21 2008 dmacvicar@suse.de
- fallback to default icon if no icon is defined in
  a pattern.
* Wed May 21 2008 coolo@suse.de
- fixing theming of pattern selector popups
* Wed May 21 2008 dmacvicar@suse.de
- display the right name for repository list. (bnc#383553)
  patch by Fabien Crespel <fabien@crespel.net>
* Mon May 19 2008 dmacvicar@suse.de
- feedback for search (bnc#391406)
- reenable cancel (bnc#350988)
- fix search begins with string (bnc#388601)
- deprecate special selection icons (bnc#392067)
- fix persistent locks saving (bnc#332853)
- 2.16.44
* Mon May 19 2008 tgoettlicher@suse.de
- Fixed bnc #389745: 'Changed Packages' window not centered
* Mon May 19 2008 dmacvicar@suse.de
- cycle status from autoselected to non-selected instead of
  taboo, as ZYpp supports soft-locks (recommends locks)
  (related to bnc#389739)
* Thu May 15 2008 sh@suse.de
- Fixed bnc #389744: Missing icons in "symbols help" dialog
- V 2.16.43
* Thu May 15 2008 dmacvicar@suse.de
- fix pattern selector unreadable font
  (bnc#381970)
- 2.16.42
* Tue May 13 2008 dmacvicar@suse.de
- show satisfied non packages as installed selectables
  (bnc#380356)
- 2.16.41
* Wed Apr 30 2008 lslezak@suse.cz
- display "Repository" menu only when requested by `opt(`repoMgr)
  option (bnc#381956)
- V 2.16.40
* Fri Apr 25 2008 dmacvicar@suse.de
- make rpm groups view use packagekit groups
  with nice icons. Get rid of useless tree
- add list of suggested and recommended packages
  (fate #302039)
- ported search to sat solver search (much faster)
  and implemented (fate #120368) to search for keywords
  enabled by default.
- 2.16.39
* Mon Apr 21 2008 dmacvicar@suse.de
- apply language selections after clicking
  (bnc #381994)
- 2.16.38
* Mon Apr 21 2008 jsrain@suse.cz
- added missing textdomain
* Fri Apr 18 2008 dmacvicar@suse.de
- make versions widget work (bnc #354983)
- show updates in blue again (bnc #371681)
- allow disabling view of debuginfo and devel pkgs
  (bnc #359155)
- 2.16.37
* Thu Apr 17 2008 dmacvicar@suse.de
- don't reorder patterns when clicking
- enable tooltip for repositories and patterns
* Thu Apr 17 2008 dmacvicar@suse.de
- fix space used when resizing
* Wed Apr 16 2008 dmacvicar@suse.de
- don't crash using keyboard on languages filter
- 2.16.36
* Wed Apr 16 2008 coolo@suse.de
- "unexcel" package management
- 2.16.35
* Tue Apr 15 2008 tgoettlicher@suse.de
- fix dependencies (bnc #377586)
- 2.16.34
* Mon Apr 14 2008 dmacvicar@suse.de
- don't crash with language right click (bnc #370233)
- show language content
- 2.16.33
* Wed Apr  9 2008 sh@suse.de
- Fixed bnc #372910: License windows shows in left top
* Wed Apr  9 2008 dmacvicar@suse.de
- fix patch and pattern content
* Wed Apr  9 2008 dmacvicar@suse.de
- fix pattern view display (only missing head font)
* Tue Apr  8 2008 dmacvicar@suse.de
- fixed some Selectable changes
- 2.16.32
* Fri Apr  4 2008 schubi@suse.de
- Fixed ResStatus (needed, satisfied,...)
- 2.16.31
* Thu Apr  3 2008 dmacvicar@suse.de
- Add unmantained packages filter (fate ##302004)
- 2.16.30
* Tue Apr  1 2008 tgoettlicher@suse.de
- Scoll licence dialogs to top (bnc #373910)
* Tue Mar 25 2008 sh@suse.de
- Changed textdomain from "packages-qt" to "qt-pkg" for consistency
* Wed Mar 19 2008 coolo@suse.de
- fix build against libzypp 4.5
* Wed Mar 19 2008 dmacvicar@suse.de
- make autodeps checkbox and button clickable (bnc #355268)
- make the @System repo show installed packages
  as expected (bnc #370228)
- don't add space between menu bar and the rest
  when resizing (bnc #370231)
* Fri Mar 14 2008 lslezak@suse.cz
- added a new menu entry for starting the repository manager
  (fate#302517)
- V 2.16.28
* Thu Mar 13 2008 sh@suse.de
- Fixed bug #370244: Menu entries about source RPMs
  Moved out all source RPM related menu entries:
  libzypp has no support whatsoever for source RPMs
* Wed Feb 27 2008 coolo@suse.de
- fix build without ycp
* Mon Feb 25 2008 sh@suse.de
- Added copy of GPL licensing terms (COPYING) (bnc #362646)
- V 2.16.27
* Mon Feb 25 2008 sh@suse.de
- Provide yast2_ui_pkg in .spec file (bnc #363958)
- V 2.16.26
* Thu Feb 14 2008 coolo@suse.de
- split off the package manager off yast2-qt
